@@ -490,7 +490,7 @@ class StringFilter(__OperatorFilter):
 
     def _check_types(self, column_type_dict):
         if column_type_dict[self.column_name] != "s":
-            raise Exception(f"A StringFilter may only be used with string columns, and {self.column_name.decode()} is not a string.")
+            raise Exception(f"A StringFilter may only be used with string columns, and {self.column_name.decode()} is not a string ({column_type_dict[self.column_name]}).")
 
 class FloatFilter(__OperatorFilter):
     def __init__(self, column_name, oper, value):
